@@ -2,6 +2,7 @@ import urllib.request
 import random
 import json
 from . import log
+from . import useragent
 import gzip
 import http.client
 import urllib.error
@@ -63,8 +64,8 @@ class Crawl:
                  shuffle: bool = False,
                  is_redirect: int or bool = False,
                  auth: tuple or list = None,
-                 protocol: str = 'http',
                  stop_code: int or str = None,
+                 allow_none: bool = False,
                  **kwargs):
         self.url = url
         self.timeout = timeout
@@ -82,6 +83,7 @@ class Crawl:
         self.auth = auth
         self.stop_code = str(stop_code)
         self.protocol = url[:url.find(':')]
+        self.allow_none = allow_none
         self.kwargs = kwargs
 
         self.html = None
@@ -142,7 +144,10 @@ class Crawl:
                             data = json.dumps(self.data)
                             data = data.encode('utf8')
                         elif self.dataType == 'str':
-                            data = urllib.parse.urlencode(self.data)
+                            if isinstance(self.data, dict):
+                                data = urllib.parse.urlencode(self.data)
+                            else:
+                                data = self.data
                             data = data.encode('utf8')
                         req = urllib.request.Request(self.url, headers=self.headers, data=data)
                     res = opener.open(req, timeout=self.timeout)
@@ -173,7 +178,10 @@ class Crawl:
                     if self.html:
                         return self.html
                     else:
-                        index += 1
+                        if not self.allow_none:
+                            index += 1
+                        else:
+                            return self.html
 
                 except http.client.BadStatusLine as e:
                     index += 1
